package ppx_string

  1. Overview
  2. Docs

Module type Ppx_string_runtime.SSource

Sourcetype t

Result type of interpolation, and of interpolated %

alues}.
Sourcetype conversion

Result type of %converted#String interpolated values. This will often be either string or t, depending on what is convenient for the configured ppx.

Sourcetype length

Type of length values for %padding#:8.

Sourceval empty : t

Empty string.

Sourceval of_string : string -> t

Literal string.

Sourceval convert : conversion -> t

Finish a conversion to t.

Sourceval concat : t list -> t

Combine multiple values in order.

Sourceval pad : t -> len:length -> t

Pad to some minimum length.

Sourceval identity : t -> t

Identity function.

Used for ensuring an argument has type t in expanded code, without needing the type t to be exported explicitly for a type annotation. See note above about destructive substitution.